{% load thumbnail %}

{% if twitter %}
	<meta name="twitter:card" content="summary_large_image">
	<meta name="twitter:site" content="{{ twitter.site }}">
	<meta name="twitter:creator" content="{{ twitter.creator }}">
	<meta name="twitter:title" content="{{ twitter.title }}">
	<meta name="twitter:description" content="{{ twitter.description }}">
	<meta name="twitter:image" content="{{ twitter.get_image_url }}">
{% endif %}